@@ -3,19 +3,26 @@ Utilities for reading CSU-CHILL CHL files.
 
 """
 
-from datetime import datetime
 import struct
+from datetime import datetime
 
 import numpy as np
 
 from ..config import FileMetadata, get_fillvalue
 from ..core.radar import Radar
-from .common import make_time_unit_str, _test_arguments, prepare_for_read
+from .common import _test_arguments, make_time_unit_str, prepare_for_read
 
 
-def read_chl(filename, field_names=None, additional_metadata=None,
-             file_field_names=None, exclude_fields=None,
-             include_fields=None, use_file_field_attributes=True, **kwargs):
+def read_chl(
+    filename,
+    field_names=None,
+    additional_metadata=None,
+    file_field_names=None,
+    exclude_fields=None,
+    include_fields=None,
+    use_file_field_attributes=True,
+    **kwargs
+):
     """
     Read a CSU-CHILL CHL file.
 
@@ -63,26 +70,33 @@ def read_chl(filename, field_names=None, additional_metadata=None,
     _test_arguments(kwargs)
 
     # create metadata retrival object
-    filemetadata = FileMetadata('chl', field_names, additional_metadata,
-                                file_field_names, exclude_fields,
-                                include_fields)
+    filemetadata = FileMetadata(
+        "chl",
+        field_names,
+        additional_metadata,
+        file_field_names,
+        exclude_fields,
+        include_fields,
+    )
 
     # read data
     chl_file = ChlFile(prepare_for_read(filename))
 
     # time
-    time = filemetadata('time')
+    time = filemetadata("time")
     tdata = np.array(chl_file.time)
     min_time = np.floor(tdata.min())
-    time['data'] = (tdata - min_time).astype('float64')
-    time['units'] = make_time_unit_str(datetime.utcfromtimestamp(min_time))
+    time["data"] = (tdata - min_time).astype("float64")
+    time["units"] = make_time_unit_str(datetime.utcfromtimestamp(min_time))
 
     # range
-    _range = filemetadata('range')
-    _range['data'] = (np.array(range(chl_file.ngates)) *
-                      chl_file.gate_spacing + chl_file.first_gate_offset)
-    _range['meters_between_gates'] = np.array(chl_file.gate_spacing)
-    _range['meters_to_center_of_first_gate'] = 0.0
+    _range = filemetadata("range")
+    _range["data"] = (
+        np.array(range(chl_file.ngates)) * chl_file.gate_spacing
+        + chl_file.first_gate_offset
+    )
+    _range["meters_between_gates"] = np.array(chl_file.gate_spacing)
+    _range["meters_to_center_of_first_gate"] = 0.0
 
     # scan_type
     scan_type = SCAN_MODE_NAMES[chl_file.scan_types[-1]]
@@ -92,73 +106,85 @@ def read_chl(filename, field_names=None, additional_metadata=None,
     for i, fdata in chl_file.fields.items():
 
         field_info = chl_file.field_info[i]
-        field_name = filemetadata.get_field_name(field_info['name'])
+        field_name = filemetadata.get_field_name(field_info["name"])
         if field_name is None:
             continue
 
         field_dic = filemetadata(field_name)
         np.ma.set_fill_value(fdata, get_fillvalue())
-        field_dic['data'] = fdata
-        field_dic['_FillValue'] = get_fillvalue()
+        field_dic["data"] = fdata
+        field_dic["_FillValue"] = get_fillvalue()
 
         if use_file_field_attributes:
-            field_dic['long_name'] = field_info['descr']
-            field_dic['units'] = field_info['units']
-            field_dic['valid_max'] = field_info['max_val']
-            field_dic['valid_min'] = field_info['min_val']
+            field_dic["long_name"] = field_info["descr"]
+            field_dic["units"] = field_info["units"]
+            field_dic["valid_max"] = field_info["max_val"]
+            field_dic["valid_min"] = field_info["min_val"]
 
         fields[field_name] = field_dic
 
     # metadata
-    metadata = filemetadata('metadata')
-    metadata['instrument_name'] = chl_file.radar_info['radar_name']
-    metadata['original_container'] = 'CHL'
+    metadata = filemetadata("metadata")
+    metadata["instrument_name"] = chl_file.radar_info["radar_name"]
+    metadata["original_container"] = "CHL"
 
     # longitude, latitude, altitude
-    latitude = filemetadata('latitude')
-    longitude = filemetadata('longitude')
-    altitude = filemetadata('altitude')
-    latitude['data'] = np.array([chl_file.radar_info['latitude']], 'f8')
-    longitude['data'] = np.array([chl_file.radar_info['longitude']], 'f8')
-    altitude['data'] = np.array([chl_file.radar_info['altitude']], 'f8')
+    latitude = filemetadata("latitude")
+    longitude = filemetadata("longitude")
+    altitude = filemetadata("altitude")
+    latitude["data"] = np.array([chl_file.radar_info["latitude"]], "f8")
+    longitude["data"] = np.array([chl_file.radar_info["longitude"]], "f8")
+    altitude["data"] = np.array([chl_file.radar_info["altitude"]], "f8")
 
     # sweep_number, sweep_mode, fixed_angle, sweep_start_ray_index,
     # sweep_end_ray_index
-    sweep_number = filemetadata('sweep_number')
-    sweep_mode = filemetadata('sweep_mode')
-    fixed_angle = filemetadata('fixed_angle')
-    sweep_start_ray_index = filemetadata('sweep_start_ray_index')
-    sweep_end_ray_index = filemetadata('sweep_end_ray_index')
-    sweep_number['data'] = np.arange(chl_file.num_sweeps, dtype='int32')
-    sweep_mode['data'] = np.array(
-        [SCAN_MODE_NAMES[i] for i in chl_file.scan_types], dtype='S')
-    fixed_angle['data'] = np.array(chl_file.fixed_angle, dtype='float32')
+    sweep_number = filemetadata("sweep_number")
+    sweep_mode = filemetadata("sweep_mode")
+    fixed_angle = filemetadata("fixed_angle")
+    sweep_start_ray_index = filemetadata("sweep_start_ray_index")
+    sweep_end_ray_index = filemetadata("sweep_end_ray_index")
+    sweep_number["data"] = np.arange(chl_file.num_sweeps, dtype="int32")
+    sweep_mode["data"] = np.array(
+        [SCAN_MODE_NAMES[i] for i in chl_file.scan_types], dtype="S"
+    )
+    fixed_angle["data"] = np.array(chl_file.fixed_angle, dtype="float32")
 
     ray_count = chl_file.rays_per_sweep
-    ssri = np.cumsum(np.append([0], ray_count[:-1])).astype('int32')
-    sweep_start_ray_index['data'] = ssri
-    sweep_end_ray_index['data'] = np.cumsum(ray_count).astype('int32') - 1
+    ssri = np.cumsum(np.append([0], ray_count[:-1])).astype("int32")
+    sweep_start_ray_index["data"] = ssri
+    sweep_end_ray_index["data"] = np.cumsum(ray_count).astype("int32") - 1
 
     # azimuth, elevation
-    azimuth = filemetadata('azimuth')
-    elevation = filemetadata('elevation')
-    azimuth['data'] = np.array(chl_file.azimuth, dtype='float32')
-    elevation['data'] = np.array(chl_file.elevation, dtype='float32')
+    azimuth = filemetadata("azimuth")
+    elevation = filemetadata("elevation")
+    azimuth["data"] = np.array(chl_file.azimuth, dtype="float32")
+    elevation["data"] = np.array(chl_file.elevation, dtype="float32")
 
     # instrument parameters
     instrument_parameters = None
 
     chl_file.close()
     return Radar(
-        time, _range, fields, metadata, scan_type,
-        latitude, longitude, altitude,
-        sweep_number, sweep_mode, fixed_angle, sweep_start_ray_index,
+        time,
+        _range,
+        fields,
+        metadata,
+        scan_type,
+        latitude,
+        longitude,
+        altitude,
+        sweep_number,
+        sweep_mode,
+        fixed_angle,
+        sweep_start_ray_index,
         sweep_end_ray_index,
-        azimuth, elevation,
-        instrument_parameters=instrument_parameters)
+        azimuth,
+        elevation,
+        instrument_parameters=instrument_parameters,
+    )
 
 
-class ChlFile(object):
+class ChlFile:
     """
     A file object for CHL data.
 
@@ -229,18 +255,18 @@ class ChlFile(object):
         self.first_gate_offset = None
 
         # private attributes
-        self._dstring = b''     # string containing field data.
-        self._bit_mask = None   # bit mask specifying fields present in file.
-        self._dtype = None      # NumPy dtype for a single gate (all fields).
+        self._dstring = b""  # string containing field data.
+        self._bit_mask = None  # bit mask specifying fields present in file.
+        self._dtype = None  # NumPy dtype for a single gate (all fields).
         self._ray_bsize = None  # size in bytes of a single ray (all fields).
-        self._packets = []      # List of packets, not set if debug is False.
-        self._field_nums = None     # Field number available in file.
+        self._packets = []  # List of packets, not set if debug is False.
+        self._field_nums = None  # Field number available in file.
         self._rays_in_current_sweep = None  # accumulator for counting rays.
-        self._fh = None         # file handler
+        self._fh = None  # file handler
         self._include_ns_time = ns_time
 
         # read all blocks from the file
-        if hasattr(filename, 'read'):
+        if hasattr(filename, "read"):
             self._fh = filename
         else:
             self._fh = open(filename, "rb")
@@ -254,13 +280,13 @@ class ChlFile(object):
         self.rays_per_sweep.append(self._rays_in_current_sweep)
 
     def close(self):
-        """ Close the file. """
+        """Close the file."""
         self._fh.close()
 
     def _read_block(self):
-        """ Read a block from an open CHL file. """
+        """Read a block from an open CHL file."""
         pld = self._fh.read(8)
-        if pld == b'':
+        if pld == b"":
             return None
         block_id, length = struct.unpack("<2i", pld)
         payload = self._fh.read(length - 8)
@@ -282,48 +308,47 @@ class ChlFile(object):
             packet = self._parse_sweep_block(payload)
         else:
             packet = {}
-        packet['block_id'] = block_id
-        packet['length'] = length
+        packet["block_id"] = block_id
+        packet["length"] = length
         return packet
 
     # Block parsers
     def _parse_file_hdr_block(self, payload):
-        """ Parse a field_hdr block. """
+        """Parse a field_hdr block."""
         return _unpack_structure(payload, ARCH_FILE_HDR_T)
 
     def _parse_field_scale_block(self, payload):
-        """ Parse a field_scale block. Add scale to field_info attr. """
+        """Parse a field_scale block. Add scale to field_info attr."""
         packet = _unpack_structure(payload, FIELD_SCALE_T)
-        packet['name'] = packet['name'].decode('utf-8').rstrip('\x00')
-        packet['units'] = packet['units'].decode('utf-8').rstrip('\x00')
-        packet['descr'] = packet['descr'].decode('utf-8').rstrip('\x00')
-        self.field_info[packet['bit_mask_pos']] = packet
+        packet["name"] = packet["name"].decode("utf-8").rstrip("\x00")
+        packet["units"] = packet["units"].decode("utf-8").rstrip("\x00")
+        packet["descr"] = packet["descr"].decode("utf-8").rstrip("\x00")
+        self.field_info[packet["bit_mask_pos"]] = packet
         return packet
 
     def _parse_radar_info_block(self, payload):
-        """ Parse a radar_info block. Update metadata attribute. """
+        """Parse a radar_info block. Update metadata attribute."""
         packet = _unpack_structure(payload, RADAR_INFO_T)
-        packet['radar_name'] = (
-            packet['radar_name'].decode('utf-8').rstrip('\x00'))
+        packet["radar_name"] = packet["radar_name"].decode("utf-8").rstrip("\x00")
         self.radar_info = packet.copy()
         return packet
 
     def _parse_processor_info_block(self, payload):
-        """ Parse a processor_info block. Set dr attribute. """
+        """Parse a processor_info block. Set dr attribute."""
         packet = _unpack_structure(payload, PROCESSOR_INFO)
-        self.gate_spacing = packet['gate_spacing']
-        self.first_gate_offset = packet['range_offset']
+        self.gate_spacing = packet["gate_spacing"]
+        self.first_gate_offset = packet["range_offset"]
         self.processor_info = packet.copy()
         return packet
 
     def _parse_scan_seg_block(self, payload):
-        """ Parse a scan_seg_block. Update sweep attributes. """
+        """Parse a scan_seg_block. Update sweep attributes."""
         packet = _unpack_structure(payload, SCAN_SEG)
-        self.sweep_number.append(packet['sweep_num'])
-        self.fixed_angle.append(packet['current_fixed_angle'])
-        self.scan_types.append(packet['scan_type'])
+        self.sweep_number.append(packet["sweep_num"])
+        self.fixed_angle.append(packet["current_fixed_angle"])
+        self.scan_types.append(packet["scan_type"])
         if self.rays_per_sweep is None:
-            self.rays_per_sweep = []    # first sweep block
+            self.rays_per_sweep = []  # first sweep block
             self._rays_in_current_sweep = 0
         else:
             self.rays_per_sweep.append(self._rays_in_current_sweep)
@@ -331,47 +356,49 @@ class ChlFile(object):
         return packet
 
     def _parse_sweep_block(self, payload):
-        """ Parse a sweep block. Set num_sweeps attribute. """
+        """Parse a sweep block. Set num_sweeps attribute."""
         packet = {}
-        packet['num_sweeps'] = struct.unpack('I', payload[0:4])[0]
-        packet['swp_offsets'] = struct.unpack(
-            str(packet['num_sweeps']) + 'Q', payload[4:])
-        self.num_sweeps = packet['num_sweeps']
+        packet["num_sweeps"] = struct.unpack("I", payload[0:4])[0]
+        packet["swp_offsets"] = struct.unpack(
+            str(packet["num_sweeps"]) + "Q", payload[4:]
+        )
+        self.num_sweeps = packet["num_sweeps"]
         return packet
 
     def _parse_ray_hdr_block(self, payload):
-        """ Parse a ray_hdr block. Update associated attributes. """
+        """Parse a ray_hdr block. Update associated attributes."""
         packet = _unpack_structure(payload, ARCH_RAY_HEADER)
 
         if self._bit_mask is None:
             # this is the first ray_hdr block read
-            self.ngates = packet['gates']
-            self._bit_mask = packet['bit_mask']
+            self.ngates = packet["gates"]
+            self._bit_mask = packet["bit_mask"]
             self._field_nums = [b for b in range(38) if self._bit_mask & 2**b]
-            self._dtype = ','.join([DATA_FORMAT[self.field_info[i]['format']]
-                                    for i in self._field_nums])
-            self._ray_bsize = np.dtype(self._dtype).itemsize * packet['gates']
+            self._dtype = ",".join(
+                [DATA_FORMAT[self.field_info[i]["format"]] for i in self._field_nums]
+            )
+            self._ray_bsize = np.dtype(self._dtype).itemsize * packet["gates"]
         else:
             # check that the bit_mask and number of gates are constant
-            if packet['bit_mask'] != self._bit_mask:
-                raise NotImplementedError('bit_mask is not consistent.')
-            if packet['gates'] != self.ngates:
-                raise NotImplementedError('number of gates vary.')
+            if packet["bit_mask"] != self._bit_mask:
+                raise NotImplementedError("bit_mask is not consistent.")
+            if packet["gates"] != self.ngates:
+                raise NotImplementedError("number of gates vary.")
 
         # store ray data and pointing data
         self._dstring += self._fh.read(self._ray_bsize)
         if self._include_ns_time:
-            self.time.append(packet['time'] + packet['ns_time']/1e9)
+            self.time.append(packet["time"] + packet["ns_time"] / 1e9)
         else:
-            self.time.append(packet['time'])
-        self.azimuth.append(packet['azimuth'])
-        self.elevation.append(packet['elevation'])
+            self.time.append(packet["time"])
+        self.azimuth.append(packet["azimuth"])
+        self.elevation.append(packet["elevation"])
         self._rays_in_current_sweep += 1
 
         return packet
 
     def _extract_fields(self):
-        """ Extract field data from _dstring attribute post read. """
+        """Extract field data from _dstring attribute post read."""
         all_data = np.frombuffer(self._dstring, dtype=self._dtype)
         all_data = all_data.reshape(-1, self.ngates)
         for i, field_num in enumerate(self._field_nums):
@@ -379,28 +406,29 @@ class ChlFile(object):
             fdata = np.ma.masked_values(all_data[all_data.dtype.names[i]], 0)
             # apply scale and offset factors to interger data types
             if issubclass(fdata.dtype.type, np.integer):
-                dat_factor = float(self.field_info[field_num]['dat_factor'])
-                dat_bias = float(self.field_info[field_num]['dat_bias'])
-                fld_factor = float(self.field_info[field_num]['fld_factor'])
+                dat_factor = float(self.field_info[field_num]["dat_factor"])
+                dat_bias = float(self.field_info[field_num]["dat_bias"])
+                fld_factor = float(self.field_info[field_num]["fld_factor"])
                 fdata = (fdata * dat_factor + dat_bias) / fld_factor
 
             self.fields[field_num] = fdata
         return
 
+
 # CHL packet types
 ARCH_FORMAT_VERSION = 0x00010000
-ARCH_ID_CONTROL = 0x5aa80001
-ARCH_ID_FIELD_SCALE = 0x5aa80002
-ARCH_ID_RAY_HDR = 0x5aa80003
-ARCH_ID_FILE_HDR = 0x5aa80004
-ARCH_ID_SWEEP_BLOCK = 0x5aa80005
-HSK_ID_PROCESSOR_INFO = 0x5aa50003
-HSK_ID_RADAR_INFO = 0x5aa50001
-HSK_ID_SCAN_SEG = 0x5aa50002
+ARCH_ID_CONTROL = 0x5AA80001
+ARCH_ID_FIELD_SCALE = 0x5AA80002
+ARCH_ID_RAY_HDR = 0x5AA80003
+ARCH_ID_FILE_HDR = 0x5AA80004
+ARCH_ID_SWEEP_BLOCK = 0x5AA80005
+HSK_ID_PROCESSOR_INFO = 0x5AA50003
+HSK_ID_RADAR_INFO = 0x5AA50001
+HSK_ID_SCAN_SEG = 0x5AA50002
 
 # Additional constants
-SCAN_MODE_NAMES = ['ppi', 'rhi', 'fixed', 'manual ppi', 'manual rhi', 'idle']
-DATA_FORMAT = ['uint8', 'uint64', 'float32', 'uint16']
+SCAN_MODE_NAMES = ["ppi", "rhi", "fixed", "manual ppi", "manual rhi", "idle"]
+DATA_FORMAT = ["uint8", "uint64", "float32", "uint16"]
 
 ##############
 # Structures #
@@ -408,119 +436,120 @@ DATA_FORMAT = ['uint8', 'uint64', 'float32', 'uint16']
 
 
 def _unpack_structure(string, structure):
-    """ Unpack a structure. """
-    fmt = ''.join([i[1] for i in structure])
+    """Unpack a structure."""
+    fmt = "".join([i[1] for i in structure])
     tpl = struct.unpack(fmt, string)
     return dict(zip([i[0] for i in structure], tpl))
 
+
 ARCH_FILE_HDR_T = (
-    ('version', 'I'),
-    ('creation_version', 'I'),
-    ('creator_id', '32s'),
-    ('sweep_table_offset', 'Q'),
+    ("version", "I"),
+    ("creation_version", "I"),
+    ("creator_id", "32s"),
+    ("sweep_table_offset", "Q"),
 )
 
 ARCH_RAY_HEADER = (
-    ('azimuth', 'f'),
-    ('elevation', 'f'),
-    ('azimuth_width', 'f'),
-    ('elevation_width', 'f'),
-    ('gates', 'H'),
-    ('beam_index', 'H'),
-    ('ns_time', 'I'),
-    ('time', 'Q'),
-    ('bit_mask', 'Q'),
-    ('ray_number', 'I'),
-    ('num_pulses', 'I'),
+    ("azimuth", "f"),
+    ("elevation", "f"),
+    ("azimuth_width", "f"),
+    ("elevation_width", "f"),
+    ("gates", "H"),
+    ("beam_index", "H"),
+    ("ns_time", "I"),
+    ("time", "Q"),
+    ("bit_mask", "Q"),
+    ("ray_number", "I"),
+    ("num_pulses", "I"),
 )
 
 FIELD_SCALE_T = (
-    ('format', 'i'),
-    ('min_val', 'f'),
-    ('max_val', 'f'),
-    ('bit_mask_pos', 'i'),
-    ('type_hint', 'i'),
-    ('fld_factor', 'i'),
-    ('dat_factor', 'i'),
-    ('dat_bias', 'i'),
-    ('name', '32s'),
-    ('units', '32s'),
-    ('descr', '128s')
+    ("format", "i"),
+    ("min_val", "f"),
+    ("max_val", "f"),
+    ("bit_mask_pos", "i"),
+    ("type_hint", "i"),
+    ("fld_factor", "i"),
+    ("dat_factor", "i"),
+    ("dat_bias", "i"),
+    ("name", "32s"),
+    ("units", "32s"),
+    ("descr", "128s"),
 )
 
 RADAR_INFO_T = (
-    ('radar_name', '32s'),
-    ('latitude', 'f'),
-    ('longitude', 'f'),
-    ('altitude', 'f'),
-    ('beamwidth', 'f'),
-    ('wavelength_cm', 'f'),
-    ('unused1', 'f'),
-    ('unused2', 'f'),
-    ('unused3', 'f'),
-    ('unused4', 'f'),
-    ('gain_ant_h', 'f'),
-    ('gain_ant_v', 'f'),
-    ('zdr_cal_base', 'f'),
-    ('phidp_rot', 'f'),
-    ('base_radar_constant', 'f'),
-    ('unused5', 'f'),
-    ('power_measurement_loss_h', 'f'),
-    ('power_measurement_loss_v', 'f'),
-    ('zdr_cal_base_vhs', 'f'),
-    ('test_power_h', 'f'),
-    ('test_power_v', 'f'),
-    ('dc_loss_h', 'f'),
-    ('dc_loss_v', 'f'),
+    ("radar_name", "32s"),
+    ("latitude", "f"),
+    ("longitude", "f"),
+    ("altitude", "f"),
+    ("beamwidth", "f"),
+    ("wavelength_cm", "f"),
+    ("unused1", "f"),
+    ("unused2", "f"),
+    ("unused3", "f"),
+    ("unused4", "f"),
+    ("gain_ant_h", "f"),
+    ("gain_ant_v", "f"),
+    ("zdr_cal_base", "f"),
+    ("phidp_rot", "f"),
+    ("base_radar_constant", "f"),
+    ("unused5", "f"),
+    ("power_measurement_loss_h", "f"),
+    ("power_measurement_loss_v", "f"),
+    ("zdr_cal_base_vhs", "f"),
+    ("test_power_h", "f"),
+    ("test_power_v", "f"),
+    ("dc_loss_h", "f"),
+    ("dc_loss_v", "f"),
 )
 
 PROCESSOR_INFO = (
-    ('polarization_mode', 'i'),
-    ('processing_mode', 'i'),
-    ('pulse_type', 'i'),
-    ('test_type', 'i'),
-    ('integration_cycle_pulses', 'I'),
-    ('clutter_filter_number', 'I'),
-    ('range_gate_averaging', 'I'),
-    ('indexed_beam_width', 'f'),
-    ('gate_spacing', 'f'),
-    ('prt_usec', 'f'),
-    ('range_start', 'f'),
-    ('range_stop', 'f'),
-    ('max_gate', 'I'),
-    ('test_power', 'f'),
-    ('unused1', 'f'),
-    ('unused2', 'f'),
-    ('test_pulse_range', 'f'),
-    ('test_pulse_length', 'f'),
-    ('prt2', 'f'),
-    ('range_offset', 'f'),
+    ("polarization_mode", "i"),
+    ("processing_mode", "i"),
+    ("pulse_type", "i"),
+    ("test_type", "i"),
+    ("integration_cycle_pulses", "I"),
+    ("clutter_filter_number", "I"),
+    ("range_gate_averaging", "I"),
+    ("indexed_beam_width", "f"),
+    ("gate_spacing", "f"),
+    ("prt_usec", "f"),
+    ("range_start", "f"),
+    ("range_stop", "f"),
+    ("max_gate", "I"),
+    ("test_power", "f"),
+    ("unused1", "f"),
+    ("unused2", "f"),
+    ("test_pulse_range", "f"),
+    ("test_pulse_length", "f"),
+    ("prt2", "f"),
+    ("range_offset", "f"),
 )
 
 SCAN_SEG = (
-    ('az_manual', 'f'),
-    ('el_manual', 'f'),
-    ('az_start', 'f'),
-    ('el_start', 'f'),
-    ('scan_rate', 'f'),
-    ('segname', '24s'),
-    ('opt', 'i'),
-    ('follow_mode', 'i'),
-    ('scan_type', 'i'),
-    ('scan_flags', 'I'),
-    ('volume_num', 'I'),
-    ('sweep_num', 'I'),
-    ('time_limit', 'I'),
-    ('webtilt', 'I'),
-    ('left_limit', 'f'),
-    ('right_limit', 'f'),
-    ('up_limit', 'f'),
-    ('down_limit', 'f'),
-    ('step', 'f'),
-    ('max_sweeps', 'I'),
-    ('filter_break_sweep', 'I'),
-    ('clutter_filter1', 'I'),
-    ('clutter_filter2', 'I'),
-    ('project', '16s'),
-    ('current_fixed_angle', 'f'),
+    ("az_manual", "f"),
+    ("el_manual", "f"),
+    ("az_start", "f"),
+    ("el_start", "f"),
+    ("scan_rate", "f"),
+    ("segname", "24s"),
+    ("opt", "i"),
+    ("follow_mode", "i"),
+    ("scan_type", "i"),
+    ("scan_flags", "I"),
+    ("volume_num", "I"),
+    ("sweep_num", "I"),
+    ("time_limit", "I"),
+    ("webtilt", "I"),
+    ("left_limit", "f"),
+    ("right_limit", "f"),
+    ("up_limit", "f"),
+    ("down_limit", "f"),
+    ("step", "f"),
+    ("max_sweeps", "I"),
+    ("filter_break_sweep", "I"),
+    ("clutter_filter1", "I"),
+    ("clutter_filter2", "I"),
+    ("project", "16s"),
+    ("current_fixed_angle", "f"),
 )
